import { request } from '@/utils/request';

import type {
  addThemeDTO,
  addThemeMenuDto,
  delThemeDto,
  getMenuTreeWithThemeTagDto
} from '@/types/BiTheme';

/**
 * 新增主题
 * @param data
 * @returns
 */
const addTheme = (data: addThemeDTO) => {
  return request<any>('/bi-manager/theme/addTheme', 'POST', data);
};

/**
 * 保存主题关联的菜单
 * @param addThemeMenuDto
 * @returns
 */
const addThemeMenu = (data: addThemeMenuDto) => {
  return request<any>('/bi-manager/theme/addThemeMenu', 'POST', data);
};

/**
 * 删除主题
 * @param delThemeDto
 * @returns
 */
const delTheme = (data: delThemeDto) => {
  return request<any>('/bi-manager/theme/delTheme', 'POST', data);
};

/**
 * 修改主题
 * @param addThemeDTO
 * @returns
 */
const editTheme = (data: addThemeDTO & { themeId: string }) => {
  return request<any>('/bi-manager/theme/editTheme', 'POST', data);
};

/**
 * 获取主题关联的菜单树
 * @param data
 * @returns
 */
const getMenuTreeWithThemeTag = (data: getMenuTreeWithThemeTagDto) => {
  return request('/bi-manager/theme/getMenuTreeWithThemeTag', 'POST', data);
};

/**
 * 查询主题
 * @param data
 * @returns
 */
const getThemeList = (data = {}) => {
  return request<any>('/bi-manager/theme/getThemeList', 'POST', data);
};

export default {
  addTheme,
  addThemeMenu,
  delTheme,
  editTheme,
  getMenuTreeWithThemeTag,
  getThemeList
};
